@@ -9,8 +9,14 @@ module Helpers
     using_bun? ? "bun run" : "yarn"
   end
 
+  def bundler_x_cmd
+    using_bun? ? "bunx" : "npx"
+  end
+
   def using_bun?
-    File.exist?('bun.lockb') || (tool_exists?('bun') && !File.exist?('yarn.lock'))
+    tool_exists?('bun') && (File.exist?('bun.lockb') || 
+                            File.exist?('bun.lock') ||       
+                            File.exist?('yarn.lock'))
   end
 
   def tool_exists?(tool)
