@@ -20,21 +20,23 @@ end
 say "Remove app/assets/stylesheets/application.css so build output can take over"
 remove_file "app/assets/stylesheets/application.css"
 
-if (app_layout_path = Rails.root.join("app/views/layouts/application.html.erb")).exist?
-  say "Add stylesheet link tag in application layout"
-  insert_into_file(
-    app_layout_path.to_s,
-    defined?(Turbo) ?
-      %(\n    <%= stylesheet_link_tag "application", "data-turbo-track": "reload" %>) :
-      %(\n    <%= stylesheet_link_tag "application" %>),
-    before: /\s*<\/head>/
-  )
-else
-  say "Default application.html.erb is missing!", :red
-  if defined?(Turbo)
-    say %(        Add <%= stylesheet_link_tag "application", "data-turbo-track": "reload" %> within the <head> tag in your custom layout.)
+if Rails::VERSION::MAJOR < 8
+  if (app_layout_path = Rails.root.join("app/views/layouts/application.html.erb")).exist?
+    say "Add stylesheet link tag in application layout"
+    insert_into_file(
+      app_layout_path.to_s,
+      defined?(Turbo) ?
+        %(\n    <%= stylesheet_link_tag "application", "data-turbo-track": "reload" %>) :
+        %(\n    <%= stylesheet_link_tag "application" %>),
+      before: /\s*<\/head>/
+    )
   else
-    say %(        Add <%= stylesheet_link_tag "application" %> within the <head> tag in your custom layout.)
+    say "Default application.html.erb is missing!", :red
+    if defined?(Turbo)
+      say %(        Add <%= stylesheet_link_tag "application", "data-turbo-track": "reload" %> within the <head> tag in your custom layout.)
+    else
+      say %(        Add <%= stylesheet_link_tag "application" %> within the <head> tag in your custom layout.)
+    end
   end
 end
 
